import click
from sh import git
import activegit

@click.command()
@click.argument('repopath', type=str)
@click.option('--bare', type=bool, default=True)
@click.option('--shared', type=str, default='group')
def initrepo(repopath, bare, shared):
    """ Initialize an activegit repo. 
    Default makes base shared repo that should be cloned for users """

    ag = activegit.ActiveGit(repopath, bare=bare, shared=shared)


@click.command()
@click.argument('barerepo', type=str)
@click.argument('userrepo', type=str)
def clonerepo(barerepo, userrepo):
    """ Clone a bare base repo to a user """

    git.clone(barerepo, userrepo)
    ag = activegit.ActiveGit(userrepo)



from setuptools import setup, find_packages

setup(
    name = 'activegit',
    description = 'Uses git for distributed active learning',
    author = 'Casey Law, Umaa Rebbapragada',
    author_email = 'caseyjlaw@gmail.com',
    version = '0.35',
    url = 'http://github.com/caseyjlaw/activegit',
    packages = find_packages(),        # get all python scripts in real time
    install_requires=['sh', 'scikit-learn'],
    entry_points='''
        [console_scripts]
        aginit=activegit.cli:initrepo
        agclone=activegit.cli:clonerepo
'''

)
